@@ -873,6 +873,140 @@ static char* cp850 [] = {
 /* 0xfe */  "&#9632;", /* black square */
 /* 0xff */  "&nbsp;",
 };
+#if 1 /* daved - 0.20.3 */
+static char *Greek[] = /* Times New Roman Greek */
+{
+/* 0x80 */  "&euro;",
+/* 0x81 */  0,
+/* 0x82 */  "&sbquo;",
+/* 0x83 */  "&fnof;",
+/* 0x84 */  "&bdquo;",
+/* 0x85 */  "&hellip;",
+/* 0x86 */  "&dagger;",
+/* 0x87 */  "&Dagger;",
+/* 0x88 */  "&circ;",
+/* 0x89 */  "&permil;",
+/* 0x8a */  "&Scaron;",
+/* 0x8b */  "&lsaquo;",
+/* 0x8c */  "&OElig;",
+/* 0x8d */  0,	/* RI ? */
+/* 0x8e */  "&#142;",	/* Z caron */
+/* 0x8f */  0,  /* SS3 */
+/* 0x90 */  0,	/* DCS */
+/* 0x91 */  "&lsquo;",
+/* 0x92 */  "&rsquo;",
+/* 0x93 */  "&ldquo;",
+/* 0x94 */  "&rdquo;",
+/* 0x95 */  "&bull;",
+/* 0x96 */  "&ndash;",
+/* 0x97 */  "&mdash;",
+/* 0x98 */  "&tilde;",
+/* 0x99 */  "&trade;",
+/* 0x9a */  "&scaron",
+/* 0x9b */  "&rsaquo;",
+/* 0x9c */  "&oelig;",
+/* 0x9d */  0, /* OSC ?? */
+/* 0x9e */  "&#158;",	/* z caron */
+/* 0x9f */  "&Yuml;",
+/* 0xa0 */  "&nbsp;",
+/* 0xa1 */  "&#901;", /* combined umlaut and acute accent */
+/* 0xa2 */  "&#902;", /* 'A */
+/* 0xa3 */  "&pound;",
+/* 0xa4 */  "&curren;",
+/* 0xa5 */  "&yen;",
+/* 0xa6 */  "&brvbar;",
+/* 0xa7 */  "&sect;",
+/* 0xa8 */  "&uml;",
+/* 0xa9 */  "&copy;",
+/* 0xaa */  "&#63737;", /* top & left rectangle */
+/* 0xab */  "&laquo;",
+/* 0xac */  "&not;",
+/* 0xad */  "&minus;",
+/* 0xae */  "&reg;",
+/* 0xaf */  "&mdash;",
+/* 0xb0 */  "&deg;",
+/* 0xb1 */  "&plusmn;",
+/* 0xb2 */  "&sup2;",
+/* 0xb3 */  "&sup3;",
+/* 0xb4 */  "&acute;",
+/* 0xb5 */  "&micro;",
+/* 0xb6 */  "&para;",
+/* 0xb7 */  "&middot;",
+/* 0xb8 */  "&#904;",  /* 'E */
+/* 0xb9 */  "&#905;", /* 'H */
+/* 0xba */  "&#906;", /* 'I */
+/* 0xbb */  "&raquo;",
+/* 0xbc */  "&#908;", /* 'O */
+/* 0xbd */  "&frac12;",
+/* 0xbe */  "&#910;", /* 'Y */
+/* 0xbf */  "&#911;", /* 'Omega */
+/* 0xc0 */  "&#912;", /* dotless i umlaut acute */
+/* 0xc1 */  "&Alpha;",
+/* 0xc2 */  "&Beta;",
+/* 0xc3 */  "&Gamma;",
+/* 0xc4 */  "&Delta;",
+/* 0xc5 */  "&Epsilon;",
+/* 0xc6 */  "&Zeta;",
+/* 0xc7 */  "&Eta;",
+/* 0xc8 */  "&Theta;",
+/* 0xc9 */  "&Iota;",
+/* 0xca */  "&Kappa;",
+/* 0xcb */  "&Lambda;",
+/* 0xcc */  "&Mu;",
+/* 0xcd */  "&Nu;",
+/* 0xce */  "&Xi;",
+/* 0xcf */  "&Omicron;",
+/* 0xd0 */  "&Pi;",
+/* 0xd1 */  "&Rho;",
+/* 0xd2 */  "&#63738;", /* long vertical bar */
+/* 0xd3 */  "&Sigma;",
+/* 0xd4 */  "&Tau;",
+/* 0xd5 */  "&Upsilon;",
+/* 0xd6 */  "&Phi;",
+/* 0xd7 */  "&Chi;",
+/* 0xd8 */  "&Psi;",
+/* 0xd9 */  "&Omega;",
+/* 0xda */  "&#938;", /* Iota umlaut */
+/* 0xdb */  "&#939;", /* Upsilon umlaut */
+/* 0xdc */  "&#940;", /* alpha acute */
+/* 0xdd */  "&#941;", /* epsilon acute */
+/* 0xde */  "&#942;", /* eta acute */
+/* 0xdf */  "&#943;", /* iota acute */
+/* 0xe0 */  "&#944;", /* nu umlaut acute */
+/* 0xe1 */  "&alpha;",
+/* 0xe2 */  "&beta;",
+/* 0xe3 */  "&gamma;",
+/* 0xe4 */  "&delta;",
+/* 0xe5 */  "&epsilon;",
+/* 0xe6 */  "&zeta;",
+/* 0xe7 */  "&eta;",
+/* 0xe8 */  "&theta;",
+/* 0xe9 */  "&iota;",
+/* 0xea */  "&kappa;",
+/* 0xeb */  "&lambda;",
+/* 0xec */  "&mu;",
+/* 0xed */  "&nu;",
+/* 0xee */  "&xi;",
+/* 0xef */  "&omicron;",
+/* 0xf0 */  "&pi;",
+/* 0xf1 */  "&rho;",
+/* 0xf2 */  "&sigmaf;",
+/* 0xf3 */  "&sigma;",
+/* 0xf4 */  "&tau;",
+/* 0xf5 */  "&upsilon;",
+/* 0xf6 */  "&phi;",
+/* 0xf7 */  "&chi;",
+/* 0xf8 */  "&psi;",
+/* 0xf9 */  "&omega;",
+/* 0xfa */  "&#970;", /* iotauml */
+/* 0xfb */  "&#971;", /* upsilonuml */
+/* 0xfc */  "&#972;", /* omicronacute */
+/* 0xfd */  "&#973;", /* nuacute */
+/* 0xfe */  "&#974;", /* omegaacute */
+/* 0xff */  "&#63739;",
+};
+#endif
+
 
 
 
@@ -1115,6 +1249,11 @@ html_init (void)
     op->symbol_last_char = 254;
 	op->symbol_translation_table = symbol;
 #endif
+#if 1 /* daved - 0.20.3 - GREEK font support */
+	op->greek_first_char = 0x80;
+    op->greek_last_char = 0xff;
+	op->greek_translation_table = Greek;
+#endif
 
 	op->unisymbol_print = html_unisymbol_print;
 
