@@ -41,6 +41,7 @@
  * 25 Sep 04, st001906@hrz1.hrz.tu-darmstadt.de: added stdlib.h for djgpp
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requested by ZT Smith
  * 06 Jan 06, marcossamaral@terra.com.br: includes verbose mode 
+ * 24 Feb 06, daved@physiol.usyd.edu.au: avoid buffer overun in path2
  *--------------------------------------------------------------------*/
 
 #ifdef HAVE_CONFIG_H
@@ -72,6 +73,9 @@
 #include "text.h"
 #include "vt.h"
 #include "latex.h"
+#if 1 /* daved 0.20.3 */
+#include <sys/param.h>
+#endif
 
 
 
@@ -195,7 +199,11 @@ main (int argc, char **argv)
 	/* Open file for reading. Append ".rtf" to file name if not supplied. */
 	f = fopen(path, "r");
 	if (!f) {
+#if 1 /* daved 0.20.3 */
+		char path2[MAXPATHLEN+5];
+#else
 		char path2[200];
+#endif
 		strcpy(path2, path);
 		strcat(path2, ".rtf");
 		f = fopen(path2, "r");
