@@ -131,8 +131,21 @@ op_translate_char (OutputPersonality *op, int charset, CodepageInfo *codepage, i
 
 		if(ch >= start && ch <= op->symbol_last_char)
 			result = op->symbol_translation_table[ch - start];
+		if(result)
+			return result;
 	}
 	else
+#endif
+#if 1 /* daved - 0.20.3 */
+	if(ntable == FONTGREEK_TABLE)
+	{
+		start = op->greek_first_char;
+
+		if(ch >= start && ch <= op->greek_last_char)
+			result = op->greek_translation_table[ch - start];
+		if(result)
+			return result;
+	}
 #endif
 	if (ch >= 0x20 && ch < 0x80) {
 		result = op->ascii_translation_table [ch - 0x20];
@@ -146,11 +159,18 @@ op_translate_char (OutputPersonality *op, int charset, CodepageInfo *codepage, i
 	else
 	switch (charset) {
 	case CHARSET_ANSI:
-		if (codepage != NULL && op->unisymbol_print != NULL && codepage->cp) {
+		if (codepage != NULL && op->unisymbol_print != NULL && codepage->cp)
+		{
+			if(0)
+			printf("<CODEPAGE CHAR %d>", codepage->chars[ch - 0x80]);
 			if (codepage->chars[ch - 0x80]) {
+				if(0)
+				printf("<UNIPRINTING>");
 				result = op->unisymbol_print(codepage->chars[ch - 0x80]);
 			}
-		} else {
+		}
+		if(!result)
+		{
 		start = op->ansi_first_char;
 			if (ch >= start &&
 			    ch <= op->ansi_last_char)
